;**********************************************************************
;Filename:		INC_LCD_Init_4_bit_H_nib.inc	 
;Date:			Sept 14, 2010
;File Version:	1.00
;Author:		
;Objective:		Set up LCD in 4 bit mode, high nibble and write to LCD
;Notes:			
;**********************************************************************
;Initialized LCD in 4 bit mode, high nibble
LCD_not_Initialized
			BCF E_Control			;set up pic ports and pins
			BCF RS_Control
			BSF STATUS, RP0			;bank 1
			BCF E_Control
			BCF RS_Control
			
			MOVLW 0x0f				;set port for high nibble b'00001111'
			
			ANDWF LCD_Data_Port, F		;don't change the other nibble so it can be used some place else
			BCF STATUS, RP0			;bank 0
			
			LCD_MS_Delay_MAC .15000	;15ms, just a small LCD power up delay
			
			;send 0x03 b'0000 0011"	three times									
						
			MOVLW 0x33				;b'0011 0011'
			MOVWF LCD_Temp_Chr
			CALL Write_Data			
			
			LCD_MS_Delay_MAC .5000	;5ms
					
			MOVLW 0x33				; b'0011 0011'
			MOVWF LCD_Temp_Chr
			CALL Write_Data			
			
			LCD_US_Delay_MAC .100	;100us
						
			MOVLW 0x33				;b'0011 0011'
			MOVWF LCD_Temp_Chr
			CALL Write_Data			
		
			LCD_US_Delay_MAC .100	;100us
		
			MOVLW 0x22				;b'0010 0010
			MOVWF LCD_Temp_Chr		;Function set (Set interface to be 4 bits long.)
			CALL Write_Data			;Interface is 8 bits in length.
									;not required for 8 bit mode
			
									;    4 bit mode, 2 line             8 bit mode, 2 line
			MOVLW 0x28				;0x28 = b'0 0 1 0  1 0 x x'    0x38 = b'0 0 1 1  1 0 x x'
			MOVWF LCD_Temp_Chr		;         0 0 1 DL N F x x              0 0 1 DL N F x x
			CALL LCD_Write			;DL=0 4 bit, DL=1 8 bit\N=0 1 line, N=1 2 or more lines\F=0: 5x8 dots, F=1 5x10 dots
									;The number of display lines and character font cannot be changed after this point.
											
			;any standard command after this point
			MOVLW 0x0c				;b'00001100'
			MOVWF LCD_Temp_Chr
			CALL LCD_Write			;screen on, cursor and blink off
					
			MOVLW 0x06				;b'00000110'
			MOVWF LCD_Temp_Chr
			CALL LCD_Write			;auto increment Cursor
			
			BSF LCD_Flag, LCD_Initialize_bit	;LCD Initialized, set bit
			RETURN
			
;******************************************************************************************
;write to LCD in 4 bit high nibble mode
LCD_Get_Char_Write
			LCD_MS_Delay_MAC .2000	;2 ms, time between RS and E and next RS, E
									;if this delay gets below 1000 and you print a long string
									;of chars then only the last few chars will show up on the screen
			MOVF LCD_Chr_temp, W	;move char , need to keep a copy
			MOVWF LCD_Temp_Chr		;send this to the LCD
			
LCD_Write	;SWAPF LCD_Temp_Chr, F	;insert for low nibble remove for high nibble
									; it's that high nibble low nibble sequence to the LCD	
			CALL Write_Data			;send high nibble
								
			LCD_US_Delay_MAC .50	;time between data writes
			
			SWAPF LCD_Temp_Chr, F	;swap the nibbles for high nibble low nibble sequence
			CALL Write_Data			;send low nibble
			
			LCD_US_Delay_MAC .50	;time between data writes
			
			RETURN					;exit programand get next ascii/command char
						
Write_Data	BSF E_Control			;*****************start write cycle				;E to E pulse width
			MOVLW 0x0f				;for high nibble 								;is 450ns min
			;MOVLW 0xf0				;for low nibble  ;clear low nibble		
			ANDWF LCD_Data_Port, F	;                ;send 0x0 to LCD
			MOVF LCD_Temp_Chr, W	;                ;reload w
			ANDLW 0xf0				;for high nibble
			;ANDLW 0xf				;for low nibble   ;clear high nibble in w
			IORWF LCD_Data_Port, F	;                ;send data to port without affecting port high nibble
			BCF E_Control			;***********stop write cycle
			RETURN
;******************************************************************************************
