;**********************************************************************
;Filename:		INC_LCD_MAIN.inc	 
;Date:			Sept 10, 2010
;File Version:	2.00
;Author:		
;Objective:		set up program for project and send ascii characters/commands to LCD
;
;Notes:			Written for 8 bit, 4 bit high and low nibble read/write
;				Load W and call LCDPRT
;				Preceed commands with 0xfe.
;				  0xfe, call LCDPRT, command, call LCDPRT
;				
;				If connected to PORTB then Weak_pullups must be disabled
;				Ports and pins are configured during LCD Initialization
;				RS, E and R/W control and LCD_Data port can be any port and pin combination
;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
;NOTE: LCD_Flag reg must be cleared at processor Initialization, ie.. clear ram or CLRF LCD_Flag
;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
;				
;******************************** LCD CONNECTIONS ****************************************		
; LCD must be connected as follows:  LOW Nibble		HIGH Nibble		8 bit 
;      -LCD-pin	   -PIC-
;       DB4-11     PIC_port_data_bit.	0				4            0  0
;       DB5-12     PIC_port_data_bit.	1				5            1  1
;       DB6-13     PIC_port_data_bit.	2				6            2  2
;       DB7-14     PIC_port_data_bit.	3				7            3  3
;                                                                    4  4
;       E-6        PIC_port_E_control_bit x                          5  5
;		RW-5	   tie to ground for write only mode                 6  6     
;       RS-4       PIC_port_RS_control_bit x                         7  7
;		VO-3	   N/C
;       Vdd-2      5 volts
;       Vss-1      Ground
;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
; DEFINE THE PORTS AND PINS FOR YOUR PROJECT
			
			#DEFINE E_Control PORTD, 0x3	;just change the D and the bit
			#DEFINE RS_Control PORTD, 0x2
			#DEFINE LCD_Data_Port PORTD		;8 bit, 4 bit high low just change the D
			
			#DEFINE RW_Control PORTD, 0x1	;remove if not needed and tie LCD pin to ground
			;can keep but set_up pic pin for output and pull read/write low	
;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
;*********************************************	don't change below this line		
LCD_Initialize_bit	EQU		0x0
LCD_Command_bit		EQU		0x1
;******************************************************************************************
; define varables in ram
		CBLOCK
			LCD_Flag			; LCD_Initialize_bit, LCD_Command_bit and Print table delays
			LCD_Chr_temp		; is used to preserve the 0xfe, command code, ascii code
			LCD_Temp_Chr		; holds data while it is being written to lcd
		ENDC
;******************************************************************************************
;it all starts right here
LCDPRT		MOVWF LCD_Chr_temp		;save 0xfe, command code, ascii code

;******************************************************************************************
;check LCD_Initialize_bit to see if LCD needes to be Initialized
Chk_Init_bit
			BTFSC LCD_Flag, LCD_Initialize_bit	;test the bit
			GOTO LCD_chk_0xfe					;bit set, LCD Initialized
			CAll LCD_not_Initialized			;bit cleard, LCD not Initialized
;******************************************************************************************	
;check for 0xfe for command 				
LCD_chk_0xfe
			MOVF LCD_Chr_temp, W	;retrieve char
			SUBLW 0xfe
			BTFSC STATUS, Z
			goto Setflag			;char is 0xfe
			goto LCD_Wrt_Chr		;char is either a command or ascii not 0xfe
Setflag		BSF LCD_Flag, LCD_Command_bit
			RETURN	;exit program to where LCDPRT was called from to get the command that follows
					; 0xfe then back to LCDPRT to send the command
;******************************************************************************************	
LCD_Wrt_Chr	BTFSC LCD_Flag, LCD_Command_bit ; check for command or ascii
			goto Command_wrt	; if bit is set then the data is a command
			goto Data_wrt		; if bit is cleared then the data is ascii

Command_wrt	BCF RS_Control		;pull Register select pin low for command write
			BCF LCD_Flag, LCD_Command_bit ;clear the flag
			call LCD_Get_Char_Write ;to the file sellected below
			return				;exit program to get next data/char
	
Data_wrt	BSF RS_Control		;pull Register select pin high for data write
			call LCD_Get_Char_Write ;to the file sellected below
			return				;exit program to get next data/char
;******************************************************************************************
			#INCLUDE INC_LCD_Clear_ram.inc ;can remove if you don't want to clear ram to
											;save some code 
;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX				
; include the files for your project, only one from each group
;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
			;#INCLUDE INC_LCD_Init_8_bit.inc			
			#INCLUDE INC_LCD_Init_4_bit_H_nib.inc
			;#INCLUDE INC_LCD_Init_4_bit_L_nib.inc
;******************************************************
;don't include if not needed
;send the address then CALL LCD_Read	
			;#INCLUDE INC_LCD_Read_8_bit.inc
			#INCLUDE INC_LCD_Read_4_bit_H_nib.inc
			;#INCLUDE INC_LCD_Read_4_bit_L_nib.inc
;******************************************************		
			;INCLUDE INC_LCD_Delay_4mhz.inc		;if the 4 mhz doesn't work when useing the
			;#INCLUDE INC_LCD_Delay_8mhz.inc	;internal/external R/C clock then use the	
			#INCLUDE INC_LCD_Delay_20mhz.inc	;8 mhz delay this will increase the delay
												;if the R/C clock is running to fast.
												;the LCD program will run slower but I don't think
												;you will notice it. This should work because
												;when I compiled it for 20mhz, I pulled the clock and
												;inserted a 1 mhz clock and the LCD came up. of cource
												;everything ran 20 times slower and I don't know
												;if this is even a problem. As far as the LCD goes,
												; short delays bad, long delays good
